@@ -78,7 +78,10 @@ class MagickPixelPacket(ctypes.Structure):
                 ('index', ctypes.c_double)]
 
 
-libraries = load_library()
+try:
+    libraries = load_library()
+except (OSError, IOError):
+    raise ImportError('MagickWand shared library not found')
 
 #: (:class:`ctypes.CDLL`) The MagickWand library.
 library = libraries[0]
@@ -90,8 +93,15 @@ library = libraries[0]
 libmagick = libraries[1]
 
 try:
+    library.MagickWandGenesis.argtypes = []
+    library.MagickWandTerminus.argtypes = []
+
+    library.NewMagickWand.argtypes = []
     library.NewMagickWand.restype = ctypes.c_void_p
 
+    library.MagickNewImage.argtypes = [ctypes.c_void_p, ctypes.c_int,
+                                       ctypes.c_int, ctypes.c_void_p]
+
     library.DestroyMagickWand.argtypes = [ctypes.c_void_p]
     library.DestroyMagickWand.restype = ctypes.c_void_p
 
@@ -152,6 +162,10 @@ try:
     library.MagickGetImageHeight.argtypes = [ctypes.c_void_p]
     library.MagickGetImageHeight.restype = ctypes.c_size_t
 
+    library.MagickGetImageUnits.argtypes = [ctypes.c_void_p]
+
+    library.MagickSetImageUnits.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
     library.MagickGetImageDepth.argtypes = [ctypes.c_void_p]
     library.MagickGetImageDepth.restype = ctypes.c_size_t
 
@@ -167,6 +181,10 @@ try:
                                           ctypes.c_size_t, ctypes.c_int,
                                           ctypes.c_double]
 
+    library.MagickTransformImage.argtypes = [ctypes.c_void_p, ctypes.c_char_p,
+                                             ctypes.c_char_p]
+    library.MagickTransformImage.restype = ctypes.c_void_p
+
     library.MagickRotateImage.argtypes = [ctypes.c_void_p, ctypes.c_void_p,
                                           ctypes.c_double]
 
@@ -236,6 +254,8 @@ try:
     library.MagickSetIteratorIndex.argtypes = [ctypes.c_void_p,
                                                ctypes.c_ssize_t]
 
+    library.MagickGetImageType.argtypes = [ctypes.c_void_p]
+    
     library.MagickSetImageType.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
     library.MagickEvaluateImageChannel.argtypes = [ctypes.c_void_p,
@@ -273,6 +293,8 @@ if platform.system() == 'Windows':
 else:
     if platform.system() == 'Darwin':
         libc = ctypes.cdll.LoadLibrary('libc.dylib')
+    elif platform.system() == 'FreeBSD':
+        libc = ctypes.cdll.LoadLibrary(ctypes.util.find_library('c'))
     else:
         libc = ctypes.cdll.LoadLibrary('libc.so.6')
     libc.fdopen.argtypes = [ctypes.c_int, ctypes.c_char_p]
